@@ -5,17 +5,20 @@
 cubic.cov <- function(x1, x2, theta = 1, C = NA, marginal = FALSE) {
     # comments in Exp.simple.cov for more details about the
     # required parts of this covariance
-
-    if (is.matrix( x1)){
-        if(ncol(x1) != 1){
-             stop(" x is a matrix this is a  1-d covariance")}}
-
+    
+    if (is.matrix(x1)) {
+        if (ncol(x1) != 1) {
+            stop(" x is a matrix this is a  1-d covariance")
+        }
+    }
+    
     if (missing(x2)) {
         x2 <- x1
     }
     # local function
     fun.temp <- function(u, v) {
-     1+ ifelse(u < v, v * (u^2)/2 - (u^3)/6, u * (v^2)/2 - (v^3)/6)
+        1 + ifelse(u < v, v * (u^2)/2 - (u^3)/6, u * (v^2)/2 - 
+            (v^3)/6)
     }
     if (is.na(C[1]) & !marginal) {
         # cross covariance matrix
